@@ -31,6 +31,12 @@ def get_user_biz_reviews(page) -> List[ScrapedReview]:
     review_ids = get_review_ids(page)
 
     review_date_elems = get_elements_by_classname(page, "rating-qualifier")
+
+    # Exclude dates from "Previous review"
+    review_date_elems = filter(
+        lambda e: "Previous review" not in e.get_text(), review_date_elems
+    )
+
     review_dates = list(
         map(lambda e: re.search(DATE_REGEX, e.get_text()).group(), review_date_elems)
     )
